==> extjs-app-imapuser-0.2.4.tgz: package/tests/groups.config.js <==
/**
 * conjoon
 * extjs-app-imapuser
 * Copyright (C) 2017-2022 Thorsten Suckow-Homberg https://github.com/conjoon/extjs-app-imapuser
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge,
 * publish, distribute, sublicense, and/or sell copies of the Software,
 * and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
 * USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

export default [{
    group: "overrides",
    items: [
        "overrides/coon.user.view.authentication.AuthFormTest.js"
    ]
}, {
    group: "universal",
    items: [{
        group: "_issues_",
        items: [{
            group: "feat",
            items: [{
                name: "conjoon/conjoon#7",
                url: "src/_issues_/feat/conjoon%237.js"
            }]
        }]
    }, {
        group: "app",
        items: [
            "src/app/PackageControllerTest.js"
        ]
    }, {
        group: "data",
        items: [{
            name: ".request.ConfiguratorTest.js",
            url: "src/data/request/ConfiguratorTest.js"
        }]
    },
    "src/UserProviderTest.js"]
}];

==> extjs-app-imapuser-1.0.2.tgz: package/tests/groups.config.js <==
/**
 * conjoon
 * extjs-app-imapuser
 * Copyright (C) 2017-2022 Thorsten Suckow-Homberg https://github.com/conjoon/extjs-app-imapuser
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge,
 * publish, distribute, sublicense, and/or sell copies of the Software,
 * and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
 * USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

export default [{
    group: "overrides",
    items: [
        "overrides/coon.user.view.authentication.AuthFormTest.js",
        "overrides/conjoon.cn_mail.view.mail.account.MailAccountHandlerTest.js"
    ]
}, {
    group: "universal",
    items: [{
        group: "_issues_",
        items: [{
            group: "feat",
            items: [{
                name: "conjoon/conjoon#7",
                url: "src/_issues_/feat/conjoon%237.js"
            }]
        }]
    }, {
        group: "app",
        items: [
            "src/app/PackageControllerTest.js"
        ]
    }, {
        group: "data",
        items: [{
            name: ".request.ConfiguratorTest.js",
            url: "src/data/request/ConfiguratorTest.js"
        }]
    },
    "src/UserProviderTest.js"]
}];
